@@ -142,8 +142,8 @@ fn staticvec_push_u32_255(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 255>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..255 {
-      black_box(v.push(i));
+    for i in 0usize..255usize {
+      black_box(v.push(i as u32));
     }
     v[254]
   });
@@ -155,8 +155,8 @@ fn arrayvec_push_u32_255(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 255]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..255 {
-      black_box(v.push(i));
+    for i in 0usize..255usize {
+      black_box(v.push(i as u32));
     }
     v[254]
   });
@@ -168,8 +168,8 @@ fn staticvec_push_u32_512(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 512>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..512 {
-      black_box(v.push(i));
+    for i in 0usize..512usize {
+      black_box(v.push(i as u32));
     }
     v[511]
   });
@@ -181,8 +181,8 @@ fn arrayvec_push_u32_512(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 512]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..512 {
-      black_box(v.push(i));
+    for i in 0usize..512usize {
+      black_box(v.push(i as u32));
     }
     v[511]
   });
@@ -194,8 +194,8 @@ fn staticvec_push_u32_1024(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 1024>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..1024 {
-      black_box(v.push(i));
+    for i in 0usize..1024usize {
+      black_box(v.push(i as u32));
     }
     v[1023]
   });
@@ -207,8 +207,8 @@ fn arrayvec_push_u32_1024(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 1024]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..1024 {
-      black_box(v.push(i));
+    for i in 0usize..1024usize {
+      black_box(v.push(i as u32));
     }
     v[1023]
   });
@@ -220,8 +220,8 @@ fn staticvec_push_u32_2048(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 2048>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..2048 {
-      black_box(v.push(i));
+    for i in 0usize..2048usize {
+      black_box(v.push(i as u32));
     }
     v[2047]
   });
@@ -233,8 +233,8 @@ fn arrayvec_push_u32_2048(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 2048]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..2048 {
-      black_box(v.push(i));
+    for i in 0usize..2048usize {
+      black_box(v.push(i as u32));
     }
     v[2047]
   });
@@ -246,8 +246,8 @@ fn staticvec_push_u32_4096(b: &mut Bencher) {
   let mut v = StaticVec::<u32, 4096>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..4096 {
-      black_box(v.push(i));
+    for i in 0usize..4096usize {
+      black_box(v.push(i as u32));
     }
     v[4095]
   });
@@ -259,21 +259,47 @@ fn arrayvec_push_u32_4096(b: &mut Bencher) {
   let mut v = ArrayVec::<[u32; 4096]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..4096 {
-      black_box(v.push(i));
+    for i in 0usize..4096usize {
+      black_box(v.push(i as u32));
     }
     v[4095]
   });
   b.bytes = v.capacity() as u64;
 }
 
+#[bench]
+fn staticvec_push_u32_8192(b: &mut Bencher) {
+  let mut v = StaticVec::<u32, 8192>::new();
+  b.iter(|| {
+    v.clear();
+    for i in 0usize..8192usize {
+      black_box(v.push(i as u32));
+    }
+    v[8191]
+  });
+  b.bytes = v.capacity() as u64;
+}
+
+#[bench]
+fn arrayvec_push_u32_8192(b: &mut Bencher) {
+  let mut v = ArrayVec::<[u32; 8192]>::new();
+  b.iter(|| {
+    v.clear();
+    for i in 0usize..8192usize {
+      black_box(v.push(i as u32));
+    }
+    v[8191]
+  });
+  b.bytes = v.capacity() as u64;
+}
+
 #[bench]
 fn staticvec_push_u64_255(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 255>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..255 {
-      black_box(v.push(i));
+    for i in 0usize..255usize {
+      black_box(v.push(i as u64));
     }
     v[254]
   });
@@ -285,8 +311,8 @@ fn arrayvec_push_u64_255(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 255]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..255 {
-      black_box(v.push(i));
+    for i in 0usize..255usize {
+      black_box(v.push(i as u64));
     }
     v[254]
   });
@@ -298,8 +324,8 @@ fn staticvec_push_u64_512(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 512>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..512 {
-      black_box(v.push(i));
+    for i in 0usize..512usize {
+      black_box(v.push(i as u64));
     }
     v[511]
   });
@@ -311,8 +337,8 @@ fn arrayvec_push_u64_512(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 512]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..512 {
-      black_box(v.push(i));
+    for i in 0usize..512usize {
+      black_box(v.push(i as u64));
     }
     v[511]
   });
@@ -324,8 +350,8 @@ fn staticvec_push_u64_1024(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 1024>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..1024 {
-      black_box(v.push(i));
+    for i in 0usize..1024usize {
+      black_box(v.push(i as u64));
     }
     v[1023]
   });
@@ -337,8 +363,8 @@ fn arrayvec_push_u64_1024(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 1024]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..1024 {
-      black_box(v.push(i));
+    for i in 0usize..1024usize {
+      black_box(v.push(i as u64));
     }
     v[1023]
   });
@@ -350,8 +376,8 @@ fn staticvec_push_u64_2048(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 2048>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..2048 {
-      black_box(v.push(i));
+    for i in 0usize..2048usize {
+      black_box(v.push(i as u64));
     }
     v[2047]
   });
@@ -363,8 +389,8 @@ fn arrayvec_push_u64_2048(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 2048]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..2048 {
-      black_box(v.push(i));
+    for i in 0usize..2048usize {
+      black_box(v.push(i as u64));
     }
     v[2047]
   });
@@ -376,8 +402,8 @@ fn staticvec_push_u64_4096(b: &mut Bencher) {
   let mut v = StaticVec::<u64, 4096>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..4096 {
-      black_box(v.push(i));
+    for i in 0usize..4096usize {
+      black_box(v.push(i as u64));
     }
     v[4095]
   });
@@ -389,10 +415,36 @@ fn arrayvec_push_u64_4096(b: &mut Bencher) {
   let mut v = ArrayVec::<[u64; 4096]>::new();
   b.iter(|| {
     v.clear();
-    for i in 0..4096 {
-      black_box(v.push(i));
+    for i in 0usize..4096usize {
+      black_box(v.push(i as u64));
     }
     v[4095]
   });
   b.bytes = v.capacity() as u64;
 }
+
+#[bench]
+fn staticvec_push_u64_8192(b: &mut Bencher) {
+  let mut v = StaticVec::<u64, 8192>::new();
+  b.iter(|| {
+    v.clear();
+    for i in 0usize..8192usize {
+      black_box(v.push(i as u64));
+    }
+    v[8191]
+  });
+  b.bytes = v.capacity() as u64;
+}
+
+#[bench]
+fn arrayvec_push_u64_8192(b: &mut Bencher) {
+  let mut v = ArrayVec::<[u64; 8192]>::new();
+  b.iter(|| {
+    v.clear();
+    for i in 0usize..8192usize {
+      black_box(v.push(i as u64));
+    }
+    v[8191]
+  });
+  b.bytes = v.capacity() as u64;
+}
