@@ -49,9 +49,9 @@ mod trait_impls;
 #[doc(hidden)]
 pub mod utils;
 
-/// A [`Vec`](https://doc.rust-lang.org/nightly/alloc/vec/struct.Vec.html)-like struct
-/// (mostly directly API-compatible where it can be)
+/// A [`Vec`](alloc::vec::Vec)-like struct (mostly directly API-compatible where it can be)
 /// implemented with const generics around an array of fixed `N` capacity.
+#[cfg_attr(feature = "repr_c", repr(C))]
 pub struct StaticVec<T, const N: usize> {
   data: MaybeUninit<[T; N]>,
   length: usize,
@@ -111,8 +111,8 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// let v2 = StaticVec::<i32, 3>::new_from_array([1, 2, 3, 4, 5, 6]);
   /// assert_eq!(v2, [1, 2, 3]);
   /// ```
-  /// Note that StaticVec also implements [`From`](https://doc.rust-lang.org/nightly/std/convert/trait.From.html)
-  /// for both slices and static arrays, which may prove more ergonomic in some cases as it allows
+  /// Note that StaticVec also implements [`From`](core::convert::From) for both slices
+  /// and static arrays, which may prove more ergonomic in some cases as it allows
   /// for a greater degree of type inference:
   /// ```
   /// // The StaticVec on the next line is inferred to be of type `StaticVec<&'static str, 4>`.
@@ -149,8 +149,8 @@ impl<T, const N: usize> StaticVec<T, N> {
   /// Being `const` necessitates that this function can only accept arrays with a length
   /// exactly equal to the declared capacity of the resulting StaticVec, so if you do need
   /// flexibility with regards to input lengths it's recommended that you use
-  /// [`new_from_array`](crate::StaticVec::new_from_array) or the
-  /// [`From`](https://doc.rust-lang.org/nightly/std/convert/trait.From.html) implementations instead.
+  /// [`new_from_array`](crate::StaticVec::new_from_array) or the [`From`](core::convert::From)
+  /// implementations instead.
   ///
   /// Note that both forms of the [`staticvec!`] macro are implemented using
   /// [`new_from_const_array`](crate::StaticVec::new_from_const_array), so you may also prefer
@@ -163,8 +163,7 @@ impl<T, const N: usize> StaticVec<T, N> {
     }
   }
 
-  /// Returns the current length of the StaticVec.
-  /// Just as for a normal [`Vec`](https://doc.rust-lang.org/nightly/alloc/vec/struct.Vec.html),
+  /// Returns the current length of the StaticVec. Just as for a normal [`Vec`](alloc::vec::Vec),
   /// this means the number of elements that have been added to it with
   /// [`push`](crate::StaticVec::push), [`insert`](crate::StaticVec::insert), etc. except in the
   /// case that it has been set directly with the unsafe [`set_len`](crate::StaticVec::set_len)
@@ -199,7 +198,7 @@ impl<T, const N: usize> StaticVec<T, N> {
     N - self.length
   }
 
-  /// Returns the total size of the inhabited part of StaticVec (which may be zero if it has a
+  /// Returns the total size of the inhabited part of the StaticVec (which may be zero if it has a
   /// length of zero or contains ZSTs) in bytes. Specifically, the return value of this function
   /// amounts to a calculation of `size_of::<T>() * self.length`.
   #[inline(always)]
@@ -887,6 +886,71 @@ impl<T, const N: usize> StaticVec<T, N> {
     res
   }
 
+  /// Returns a new StaticVec consisting of the elements of `self` in linear order, interspersed
+  /// with a copy of `separator` between each one.
+  ///
+  /// Locally requires that `T` implements [`Copy`](core::marker::Copy) to
+  /// avoid soundness issues and also allow for a more efficient implementation than would otherwise
+  /// be possible.
+  ///
+  /// Example usage:
+  /// ```
+  /// assert_eq!(
+  ///  staticvec!["A", "B", "C", "D"].intersperse("Z"),
+  ///  ["A, "Z", B", "Z", "C", "Z", "D"]
+  /// );
+  /// ```
+  #[inline]
+  pub fn intersperse(&self, separator: T) -> StaticVec<T, { N * 2 }>
+  where T: Copy {
+    if self.is_empty() {
+      return StaticVec::new();
+    }
+    let mut res = StaticVec::new();
+    // The `as *mut T` cast here is necessary to make the type
+    // inference work properly (at the moment at least.) `rustc` still gets
+    // a bit confused by math operations done on const generic values
+    // in return types it seems.
+    let mut res_ptr = res.as_mut_ptr() as *mut T;
+    let mut self_ptr = self.as_ptr();
+    for _ in 0..self.length - 1 {
+      unsafe {
+        res_ptr.write(self_ptr.read());
+        res_ptr = res_ptr.offset(1);
+        res_ptr.write(separator);
+        res_ptr = res_ptr.offset(1);
+        self_ptr = self_ptr.offset(1);
+      }
+    }
+    unsafe { res_ptr.write(self_ptr.read()) };
+    res.length = (self.length * 2) - 1;
+    res
+  }
+
+  /// A version of [`intersperse`](crate::StaticVec::intersperse) for scenarios where `T` does not
+  /// derive [`Copy`](core::marker::Copy) but does implement [`Clone`](core::clone::Clone).
+  ///
+  /// Due to needing to call `clone()` through each individual element of `self` and also on
+  /// `separator`, this function is less efficient than
+  /// [`intersperse`](crate::StaticVec::intersperse), so
+  /// [`intersperse`](crate::StaticVec::intersperse) should be preferred whenever possible.
+  #[inline]
+  pub fn intersperse_clone(&self, separator: T) -> StaticVec<T, { N * 2 }>
+  where T: Clone {
+    if self.is_empty() {
+      return StaticVec::new();
+    }
+    let mut res = StaticVec::new();
+    unsafe {
+      for item in self.as_slice().get_unchecked(0..self.length - 1) {
+        res.push_unchecked(item.clone());
+        res.push_unchecked(separator.clone());
+      }
+      res.push_unchecked(self.get_unchecked(self.length - 1).clone());
+    }
+    res
+  }
+
   /// Returns a StaticVec containing the contents of a [`Vec`](alloc::vec::Vec) instance.
   /// If the [`Vec`](alloc::vec::Vec) has a length greater than the declared capacity of the
   /// resulting StaticVec, any contents after that point are ignored. Note that using this function
